==> com.liferay.frontend.js.loader.modules.extender-1.0.15-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/JSLoaderModulesPortalWebResources.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal;

import com.liferay.portal.servlet.delegate.ServletContextDelegate;

import javax.servlet.ServletContext;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Raymond Augé
 */
@Component(enabled = false, immediate = true)
public class JSLoaderModulesPortalWebResources {

	@Activate
	protected void activate(BundleContext bundleContext) {
		try {
			com.liferay.portal.kernel.servlet.PortalWebResources
				portalWebResources = new InternalPortalWebResources(
					_jsLoaderModulesServlet.getServletContext());

			_serviceRegistration = bundleContext.registerService(
				com.liferay.portal.kernel.servlet.PortalWebResources.class,
				portalWebResources, null);
		}
		catch (NoClassDefFoundError ncdfe) {
			throw new RuntimeException(ncdfe);
		}
	}

	@Deactivate
	protected void deactivate() {
		if (_serviceRegistration != null) {
			_serviceRegistration.unregister();
		}
	}

	@Reference
	private JSLoaderModulesServlet _jsLoaderModulesServlet;

	@Reference
	private JSLoaderModulesTracker _jsLoaderModulesTracker;

	private ServiceRegistration<?> _serviceRegistration;

	private class InternalPortalWebResources
		implements com.liferay.portal.kernel.servlet.PortalWebResources {

		@Override
		public String getContextPath() {
			return _servletContext.getContextPath();
		}

		@Override
		public long getLastModified() {
			return _jsLoaderModulesTracker.getLastModified();
		}

		@Override
		public String getResourceType() {
			return com.liferay.portal.kernel.servlet.PortalWebResourceConstants.
				RESOURCE_TYPE_JS_LOADER_MODULES;
		}

		@Override
		public ServletContext getServletContext() {
			return _servletContext;
		}

		private InternalPortalWebResources(ServletContext servletContext) {
			_servletContext = ServletContextDelegate.create(servletContext);
		}

		private final ServletContext _servletContext;

	}

}

==> com.liferay.frontend.js.loader.modules.extender-3.0.3-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/JSLoaderModulesPortalWebResources.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal;

import com.liferay.portal.kernel.servlet.PortalWebResourceConstants;
import com.liferay.portal.kernel.servlet.PortalWebResources;
import com.liferay.portal.servlet.delegate.ServletContextDelegate;

import javax.servlet.ServletContext;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Raymond Augé
 */
@Component(enabled = false, immediate = true)
public class JSLoaderModulesPortalWebResources {

	@Activate
	protected void activate(BundleContext bundleContext) {
		try {
			PortalWebResources portalWebResources =
				new InternalPortalWebResources(
					_jsLoaderModulesServlet.getServletContext());

			_serviceRegistration = bundleContext.registerService(
				PortalWebResources.class, portalWebResources, null);
		}
		catch (NoClassDefFoundError ncdfe) {
			throw new RuntimeException(ncdfe);
		}
	}

	@Deactivate
	protected void deactivate() {
		if (_serviceRegistration != null) {
			_serviceRegistration.unregister();
		}
	}

	@Reference
	private JSLoaderModulesServlet _jsLoaderModulesServlet;

	@Reference
	private JSLoaderModulesTracker _jsLoaderModulesTracker;

	private ServiceRegistration<?> _serviceRegistration;

	private class InternalPortalWebResources implements PortalWebResources {

		@Override
		public String getContextPath() {
			return _servletContext.getContextPath();
		}

		@Override
		public long getLastModified() {
			return _jsLoaderModulesTracker.getLastModified();
		}

		@Override
		public String getResourceType() {
			return PortalWebResourceConstants.RESOURCE_TYPE_JS_LOADER_MODULES;
		}

		@Override
		public ServletContext getServletContext() {
			return _servletContext;
		}

		private InternalPortalWebResources(ServletContext servletContext) {
			_servletContext = ServletContextDelegate.create(servletContext);
		}

		private final ServletContext _servletContext;

	}

}
